/* ###################################################################
**     Filename    : Events.h
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : GNU C Compiler
**     Date/Time   : 2013-05-09, 15:54, # CodeGen: 0
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         Cpu_OnNMIINT - void Cpu_OnNMIINT(void);
**
** ###################################################################*/
/*!
** @file Events.h
** @version 01.00
** @brief
**         This is user's event module.
**         Put your event handler code here.
*/         
/*!
**  @addtogroup Events_module Events module documentation
**  @{
*/         

#ifndef __Events_H
#define __Events_H
/* MODULE Events */

#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"
#include "FRTOS1.h"
#include "UTIL1.h"
#include "LEDR.h"
#include "LEDpin1.h"
#include "BitIoLdd1.h"
#include "LEDG.h"
#include "LEDpin2.h"
#include "BitIoLdd2.h"
#include "CLS1.h"
#include "AS1.h"
#include "ASerialLdd1.h"
#include "DIRRB.h"
#include "BitIoLdd4.h"
#include "DIRR.h"
#include "BitIoLdd6.h"
#include "DIRLB.h"
#include "BitIoLdd5.h"
#include "DIRL.h"
#include "BitIoLdd7.h"
#include "TU3.h"
#include "PWMR.h"
#include "PwmLdd1.h"
#include "PWML.h"
#include "PwmLdd2.h"
#include "WAIT1.h"
#include "SMAC1.h"
#include "PHY1.h"
#include "TRSVR1.h"
#include "CE1.h"
#include "BitIoLdd8.h"
#include "RESET1.h"
#include "BitIoLdd9.h"
#include "RTXEN1.h"
#include "BitIoLdd10.h"
#include "ATTN1.h"
#include "BitIoLdd11.h"
#include "IRQ1.h"
#include "ExtIntLdd1.h"
#include "SM1.h"
#include "SMasterLdd1.h"
#include "TMOUT1.h"
#include "RadioTx.h"
#include "TU_US.h"
#include "TRIG.h"
#include "SW1.h"
#include "BitIoLdd12.h"
#include "LED_IR.h"
#include "LEDpin4.h"
#include "BitIoLdd13.h"
#include "IR1.h"
#include "BitIoLdd14.h"
#include "IR2.h"
#include "BitIoLdd15.h"
#include "IR3.h"
#include "BitIoLdd16.h"
#include "IR4.h"
#include "BitIoLdd17.h"
#include "IR5.h"
#include "BitIoLdd18.h"
#include "IR6.h"
#include "BitIoLdd19.h"
#include "IR7.h"
#include "BitIoLdd20.h"
#include "IR8.h"
#include "BitIoLdd21.h"
#include "RefCnt.h"
#include "CS1.h"
#include "Platform.h"

#ifdef __cplusplus
extern "C" {
#endif 

/*
** ===================================================================
**     Event       :  Cpu_OnNMIINT (module Events)
**
**     Component   :  Cpu [MKL25Z128LK4]
**     Description :
**         This event is called when the Non maskable interrupt had
**         occurred. This event is automatically enabled when the <NMI
**         interrupt> property is set to 'Enabled'.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Cpu_OnNMIINT(void);


void FRTOS1_vApplicationStackOverflowHook(xTaskHandle pxTask, char *pcTaskName);
/*
** ===================================================================
**     Event       :  FRTOS1_vApplicationStackOverflowHook (module Events)
**
**     Component   :  FRTOS1 [FreeRTOS]
**     Description :
**         if enabled, this hook will be called in case of a stack
**         overflow.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * pxTask          - Pointer to task handle
**       * pcTaskName      - Pointer to task name
**     Returns     : Nothing
** ===================================================================
*/

void FRTOS1_vApplicationTickHook(void);
/*
** ===================================================================
**     Event       :  FRTOS1_vApplicationTickHook (module Events)
**
**     Component   :  FRTOS1 [FreeRTOS]
**     Description :
**         If enabled, this hook will be called by the RTOS for every
**         tick increment.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

void FRTOS1_vApplicationMallocFailedHook(void);
/*
** ===================================================================
**     Event       :  FRTOS1_vApplicationMallocFailedHook (module Events)
**
**     Component   :  FRTOS1 [FreeRTOS]
**     Description :
**         If enabled, the RTOS will call this hook in case memory
**         allocation failed.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

void SMAC1_ResetIndication(void);
/*
** ===================================================================
**     Event       :  SMAC1_ResetIndication (module Events)
**
**     Component   :  TRSVR1 [MC13192]
**     Description :
**         Event in case of transceiver reset.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
#if PL_HAS_RADIO
void PHY1_DataIndicationPacket(tRxPacket *sRxPacket);
#endif
/*
** ===================================================================
**     Event       :  PHY1_DataIndicationPacket (module Events)
**
**     Component   :  PHY1 [SPHY]
**     Description :
**         
**     Parameters  :
**         NAME            - DESCRIPTION
**         sRxPacket       - 
**     Returns     : Nothing
** ===================================================================
*/

/*
** ===================================================================
**     Event       :  TU_US_OnCounterRestart (module Events)
**
**     Component   :  TU_US [TimerUnit_LDD]
*/
/*!
**     @brief
**         Called if counter overflow/underflow or counter is
**         reinitialized by modulo or compare register matching.
**         OnCounterRestart event and Timer unit must be enabled. See
**         <SetEventMask> and <GetEventMask> methods. This event is
**         available only if a <Interrupt> is enabled.
**     @param
**         UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer passed as
**                           the parameter of Init method.
*/
/* ===================================================================*/
void TU_US_OnCounterRestart(LDD_TUserData *UserDataPtr);

/*
** ===================================================================
**     Event       :  TU_US_OnChannel0 (module Events)
**
**     Component   :  TU_US [TimerUnit_LDD]
*/
/*!
**     @brief
**         Called if compare register match the counter registers or
**         capture register has a new content. OnChannel0 event and
**         Timer unit must be enabled. See <SetEventMask> and
**         <GetEventMask> methods. This event is available only if a
**         <Interrupt> is enabled.
**     @param
**         UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer passed as
**                           the parameter of Init method.
*/
/* ===================================================================*/
void TU_US_OnChannel0(LDD_TUserData *UserDataPtr);

void SMAC1_OnInterrupt(void);
/*
** ===================================================================
**     Event       :  SMAC1_OnInterrupt (module Events)
**
**     Component   :  TRSVR1 [MC13192]
**     Description :
**         Event raised in case of transceiver interrupt.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

/* END Events */

#ifdef __cplusplus
}  /* extern "C" */
#endif 

#endif 
/* ifndef __Events_H*/
/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.2 [05.06]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
