/* ###################################################################
**     THIS COMPONENT MODULE IS GENERATED BY THE TOOL. DO NOT MODIFY IT.
**     Filename    : Tx3.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : RingBuffer
**     Version     : Component 01.041, Driver 01.00, CPU db: 3.00.000
**     Compiler    : GNU C Compiler
**     Date/Time   : 2015-11-08, 19:46, # CodeGen: 0
**     Abstract    :
**         This component implements a ring buffer for different integer data type.
**     Settings    :
**          Component name                                 : Tx3
**          Buffer Size                                    : 8
**     Contents    :
**         Clear           - void Tx3_Clear(void);
**         Put             - uint8_t Tx3_Put(Tx3_ElementType elem);
**         Get             - uint8_t Tx3_Get(Tx3_ElementType *elemP);
**         Peek            - uint8_t Tx3_Peek(Tx3_BufSizeType index, Tx3_ElementType *elemP);
**         Delete          - uint8_t Tx3_Delete(void);
**         NofElements     - Tx3_BufSizeType Tx3_NofElements(void);
**         NofFreeElements - Tx3_BufSizeType Tx3_NofFreeElements(void);
**         Deinit          - void Tx3_Deinit(void);
**         Init            - void Tx3_Init(void);
**
**     License   :  Open Source (LGPL)
**     Copyright : (c) Copyright Erich Styger, 2014-2015, all rights reserved.
**     Web: http://www.mcuoneclipse.com
**     This an open source software of an embedded component for Processor Expert.
**     This is a free software and is opened for education,  research  and commercial developments under license policy of following terms:
**     * This is a free software and there is NO WARRANTY.
**     * No restriction on use. You can use, modify and redistribute it for personal, non-profit or commercial product UNDER YOUR RESPONSIBILITY.
**     * Redistributions of source code must retain the above copyright notice.
** ###################################################################*/
/*!
** @file Tx3.c
** @version 01.00
** @brief
**         This component implements a ring buffer for different integer data type.
*/         
/*!
**  @addtogroup Tx3_module Tx3 module documentation
**  @{
*/         

/* MODULE Tx3. */

#include "Tx3.h"

#if Tx3_IS_REENTRANT
  #define Tx3_DEFINE_CRITICAL() CS1_CriticalVariable()
  #define Tx3_ENTER_CRITICAL()  CS1_EnterCritical()
  #define Tx3_EXIT_CRITICAL()   CS1_ExitCritical()
#else
  #define Tx3_DEFINE_CRITICAL() /* nothing */
  #define Tx3_ENTER_CRITICAL()  /* nothing */
  #define Tx3_EXIT_CRITICAL()   /* nothing */
#endif
static Tx3_ElementType Tx3_buffer[Tx3_BUF_SIZE]; /* ring buffer */
static Tx3_BufSizeType Tx3_inIdx;  /* input index */
static Tx3_BufSizeType Tx3_outIdx; /* output index */
static Tx3_BufSizeType Tx3_inSize; /* size data in buffer */
/*
** ===================================================================
**     Method      :  Tx3_Put (component RingBuffer)
**     Description :
**         Puts a new element into the buffer
**     Parameters  :
**         NAME            - DESCRIPTION
**         elem            - New element to be put into the buffer
**     Returns     :
**         ---             - Error code
** ===================================================================
*/
uint8_t Tx3_Put(Tx3_ElementType elem)
{
  uint8_t res = ERR_OK;
  Tx3_DEFINE_CRITICAL();

  Tx3_ENTER_CRITICAL();
  if (Tx3_inSize==Tx3_BUF_SIZE) {
    res = ERR_TXFULL;
  } else {
    Tx3_buffer[Tx3_inIdx] = elem;
    Tx3_inIdx++;
    if (Tx3_inIdx==Tx3_BUF_SIZE) {
      Tx3_inIdx = 0;
    }
    Tx3_inSize++;
  }
  Tx3_EXIT_CRITICAL();
  return res;
}

/*
** ===================================================================
**     Method      :  Tx3_Get (component RingBuffer)
**     Description :
**         Removes an element from the buffer
**     Parameters  :
**         NAME            - DESCRIPTION
**       * elemP           - Pointer to where to store the received
**                           element
**     Returns     :
**         ---             - Error code
** ===================================================================
*/
uint8_t Tx3_Get(Tx3_ElementType *elemP)
{
  uint8_t res = ERR_OK;
  Tx3_DEFINE_CRITICAL();

  Tx3_ENTER_CRITICAL();
  if (Tx3_inSize==0) {
    res = ERR_RXEMPTY;
  } else {
    *elemP = Tx3_buffer[Tx3_outIdx];
    Tx3_inSize--;
    Tx3_outIdx++;
    if (Tx3_outIdx==Tx3_BUF_SIZE) {
      Tx3_outIdx = 0;
    }
  }
  Tx3_EXIT_CRITICAL();
  return res;
}

/*
** ===================================================================
**     Method      :  Tx3_NofElements (component RingBuffer)
**     Description :
**         Returns the actual number of elements in the buffer.
**     Parameters  : None
**     Returns     :
**         ---             - Number of elements in the buffer.
** ===================================================================
*/
Tx3_BufSizeType Tx3_NofElements(void)
{
  return Tx3_inSize;
}

/*
** ===================================================================
**     Method      :  Tx3_NofFreeElements (component RingBuffer)
**     Description :
**         Returns the actual number of free elements/space in the
**         buffer.
**     Parameters  : None
**     Returns     :
**         ---             - Number of elements in the buffer.
** ===================================================================
*/
Tx3_BufSizeType Tx3_NofFreeElements(void)
{
  return (Tx3_BufSizeType)(Tx3_BUF_SIZE-Tx3_inSize);
}

/*
** ===================================================================
**     Method      :  Tx3_Init (component RingBuffer)
**     Description :
**         Initializes the data structure
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Tx3_Init(void)
{
  Tx3_inIdx = 0;
  Tx3_outIdx = 0;
  Tx3_inSize = 0;
}

/*
** ===================================================================
**     Method      :  Tx3_Clear (component RingBuffer)
**     Description :
**         Clear (empty) the ring buffer.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Tx3_Clear(void)
{
  Tx3_DEFINE_CRITICAL();

  Tx3_ENTER_CRITICAL();
  Tx3_Init();
  Tx3_EXIT_CRITICAL();
}

/*
** ===================================================================
**     Method      :  Tx3_Peek (component RingBuffer)
**     Description :
**         Returns an element of the buffer without removiing it.
**     Parameters  :
**         NAME            - DESCRIPTION
**         index           - Index of element. 0 peeks the top
**                           element, 1 the next, and so on.
**       * elemP           - Pointer to where to store the received
**                           element
**     Returns     :
**         ---             - Error code
** ===================================================================
*/
uint8_t Tx3_Peek(Tx3_BufSizeType index, Tx3_ElementType *elemP)
{
  uint8_t res = ERR_OK;
  int idx; /* index inside ring buffer */
  Tx3_DEFINE_CRITICAL();

  Tx3_ENTER_CRITICAL();
  if (index>=Tx3_BUF_SIZE) {
    res = ERR_OVERFLOW; /* asking for an element outside of ring buffer size */
  } else if (index<Tx3_inSize) {
    idx = (Tx3_outIdx+index)%Tx3_BUF_SIZE;
    *elemP = Tx3_buffer[idx];
  } else { /* asking for an element which does not exist */
    res = ERR_RXEMPTY;
  }
  Tx3_EXIT_CRITICAL();
  return res;
}

/*
** ===================================================================
**     Method      :  Tx3_Deinit (component RingBuffer)
**     Description :
**         Driver de-initialization
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
/**
void Tx3_Deinit(void)
{
  ** Function is implemented as macro in the header file
}
*/
/*
** ===================================================================
**     Method      :  Tx3_Delete (component RingBuffer)
**     Description :
**         Removes an element from the buffer
**     Parameters  : None
**     Returns     :
**         ---             - Error code
** ===================================================================
*/
uint8_t Tx3_Delete(void)
{
  uint8_t res = ERR_OK;
  Tx3_DEFINE_CRITICAL();

  Tx3_ENTER_CRITICAL();
  if (Tx3_inSize==0) {
    res = ERR_RXEMPTY;
  } else {
    Tx3_inSize--;
    Tx3_outIdx++;
    if (Tx3_outIdx==Tx3_BUF_SIZE) {
      Tx3_outIdx = 0;
    }
  }
  Tx3_EXIT_CRITICAL();
  return res;
}

/* END Tx3. */

/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.3 [05.09]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
